Changelog — Django Grappelli 2.14.3 documentation

# Changelog

## 2.14.4 (not yet released)

## 2.14.3 (Nov 23rd, 2020)

- Fixed: Compatibility with Django 3.1.

## 2.14.2 (May 14th, 2020)

- Fixed: Django version (3.0) with docs and quickstart.

- Fixed: Dashboard with metaclass.

- Fixed: Missing variable in RelatedObjectLookups.

- Fixed: Sortables with tuples when using StackedInlines.

- Improved: Removed six dependency.

- Improved: Changed bodyclass in order to allow adding more attributes.

- Improved: Adding Python 3.7 /3.8 to CI tests.

## 2.14.1 (February 10th, 2020)

- First release of Grappelli which is compatible with Django 3.0.